Chain class abstract
- Annotations
-
- @freezed
Constructors
Properties
- blockchain → String
-
no setterinherited
- chainId → String
-
no setterinherited
-
copyWith
→ $ChainCopyWith<
Chain> -
Create a copy of Chain
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → String
-
no setterinherited
- currency → String
-
no setterinherited
- explorerUrl → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- logo → String
-
no setterinherited
- network → String
-
no setterinherited
- parsedChainId → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited